# mypy-boto3-sesv2

[![PyPI - mypy-boto3-sesv2](https://img.shields.io/pypi/v/mypy-boto3-sesv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-sesv2)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-sesv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-sesv2)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-sesv2?color=blue)](https://pypistats.org/packages/mypy-boto3-sesv2)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.SESV2 1.17.68](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/sesv2.html#SESV2)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-sesv2 docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_sesv2/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-sesv2](#mypy-boto3-sesv2)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `SESV2` service.

```bash
python -m pip install boto3-stubs[sesv2]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[sesv2]` in your environment:
  `python -m pip install 'boto3-stubs[sesv2]'`

Both type checking and auto-complete should work for `SESV2` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[sesv2]` in your environment:
  `python -m pip install 'boto3-stubs[sesv2]'`

Both type checking and auto-complete should work for `SESV2` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[sesv2]` in your environment:
  `python -m pip install 'boto3-stubs[sesv2]'`
- Run `mypy` as usual

Type checking should work for `SESV2` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[sesv2]` in your environment:
  `python -m pip install 'boto3-stubs[sesv2]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `SESV2` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`SESV2Client` provides annotations for `boto3.client("sesv2")`.

```python
import boto3

from mypy_boto3_sesv2 import SESV2Client

client: SESV2Client = boto3.client("sesv2")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SESV2Client = session.client("sesv2")
```

### Literals

`mypy_boto3_sesv2.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_sesv2.literals import (
    BehaviorOnMxFailure,
    BulkEmailStatus,
    ContactLanguage,
    ContactListImportAction,
    DataFormat,
    DeliverabilityDashboardAccountStatus,
    DeliverabilityTestStatus,
    DimensionValueSource,
    DkimSigningAttributesOrigin,
    DkimStatus,
    EventType,
    IdentityType,
    ImportDestinationType,
    JobStatus,
    MailFromDomainStatus,
    MailType,
    ReviewStatus,
    SubscriptionStatus,
    SuppressionListImportAction,
    SuppressionListReason,
    TlsPolicy,
    WarmupStatus,
)

def check_value(value: BehaviorOnMxFailure) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_sesv2.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_sesv2.type_defs import (
    AccountDetailsTypeDef,
    BlacklistEntryTypeDef,
    BodyTypeDef,
    BulkEmailContentTypeDef,
    BulkEmailEntryResultTypeDef,
    BulkEmailEntryTypeDef,
    CloudWatchDestinationTypeDef,
    CloudWatchDimensionConfigurationTypeDef,
    ContactListDestinationTypeDef,
    ContactListTypeDef,
    ContactTypeDef,
    ContentTypeDef,
    CreateDeliverabilityTestReportResponseTypeDef,
    CreateEmailIdentityResponseTypeDef,
    CreateImportJobResponseTypeDef,
    CustomVerificationEmailTemplateMetadataTypeDef,
    DailyVolumeTypeDef,
    DedicatedIpTypeDef,
    DeliverabilityTestReportTypeDef,
    DeliveryOptionsTypeDef,
    DestinationTypeDef,
    DkimAttributesTypeDef,
    DkimSigningAttributesTypeDef,
    DomainDeliverabilityCampaignTypeDef,
    DomainDeliverabilityTrackingOptionTypeDef,
    DomainIspPlacementTypeDef,
    EmailContentTypeDef,
    EmailTemplateContentTypeDef,
    EmailTemplateMetadataTypeDef,
    EventDestinationDefinitionTypeDef,
    EventDestinationTypeDef,
    FailureInfoTypeDef,
    GetAccountResponseTypeDef,
    GetBlacklistReportsResponseTypeDef,
    GetConfigurationSetEventDestinationsResponseTypeDef,
    GetConfigurationSetResponseTypeDef,
    GetContactListResponseTypeDef,
    GetContactResponseTypeDef,
    GetCustomVerificationEmailTemplateResponseTypeDef,
    GetDedicatedIpResponseTypeDef,
    GetDedicatedIpsResponseTypeDef,
    GetDeliverabilityDashboardOptionsResponseTypeDef,
    GetDeliverabilityTestReportResponseTypeDef,
    GetDomainDeliverabilityCampaignResponseTypeDef,
    GetDomainStatisticsReportResponseTypeDef,
    GetEmailIdentityPoliciesResponseTypeDef,
    GetEmailIdentityResponseTypeDef,
    GetEmailTemplateResponseTypeDef,
    GetImportJobResponseTypeDef,
    GetSuppressedDestinationResponseTypeDef,
    IdentityInfoTypeDef,
    ImportDataSourceTypeDef,
    ImportDestinationTypeDef,
    ImportJobSummaryTypeDef,
    InboxPlacementTrackingOptionTypeDef,
    IspPlacementTypeDef,
    KinesisFirehoseDestinationTypeDef,
    ListConfigurationSetsResponseTypeDef,
    ListContactListsResponseTypeDef,
    ListContactsFilterTypeDef,
    ListContactsResponseTypeDef,
    ListCustomVerificationEmailTemplatesResponseTypeDef,
    ListDedicatedIpPoolsResponseTypeDef,
    ListDeliverabilityTestReportsResponseTypeDef,
    ListDomainDeliverabilityCampaignsResponseTypeDef,
    ListEmailIdentitiesResponseTypeDef,
    ListEmailTemplatesResponseTypeDef,
    ListImportJobsResponseTypeDef,
    ListManagementOptionsTypeDef,
    ListSuppressedDestinationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MailFromAttributesTypeDef,
    MessageTagTypeDef,
    MessageTypeDef,
    OverallVolumeTypeDef,
    PinpointDestinationTypeDef,
    PlacementStatisticsTypeDef,
    PutEmailIdentityDkimSigningAttributesResponseTypeDef,
    RawMessageTypeDef,
    ReplacementEmailContentTypeDef,
    ReplacementTemplateTypeDef,
    ReputationOptionsTypeDef,
    ReviewDetailsTypeDef,
    SendBulkEmailResponseTypeDef,
    SendCustomVerificationEmailResponseTypeDef,
    SendEmailResponseTypeDef,
    SendQuotaTypeDef,
    SendingOptionsTypeDef,
    SnsDestinationTypeDef,
    SuppressedDestinationAttributesTypeDef,
    SuppressedDestinationSummaryTypeDef,
    SuppressedDestinationTypeDef,
    SuppressionAttributesTypeDef,
    SuppressionListDestinationTypeDef,
    SuppressionOptionsTypeDef,
    TagTypeDef,
    TemplateTypeDef,
    TestRenderEmailTemplateResponseTypeDef,
    TopicFilterTypeDef,
    TopicPreferenceTypeDef,
    TopicTypeDef,
    TrackingOptionsTypeDef,
    VolumeStatisticsTypeDef,
)

def get_structure() -> AccountDetailsTypeDef:
    return {
      ...
    }
```
